Integrators
===========

Part of the noisy quantum gates approach are the Ito integrals, which
come up in the calculations many times and dependent on the pulse shape
used to implement the gates. The integration is separated into this
class to allow for multiple integration methods, unit testing, and
caching.

.. _integrators_theory:


Theory
------

Coming soon.

.. _integrators_classes:

Classes
-------


.. _integrator:

Integrator
~~~~~~~~~~

Coming soon.
